varying mediump vec2 var_texcoord0;

uniform lowp sampler2D texture_sampler;
uniform lowp vec4 tint;
uniform highp vec4 start_stop;

#define PI 3.141592653584

float atan2(in float y, in float x)
{
    return x == 0.0 ? sign(y) * PI / 2.0 : atan(y, x);
}

void main()
{
    // angle of the current fragment with respect to the center of the sprite
    float angle = atan2( var_texcoord0.y - 0.5, var_texcoord0.x - 0.5);
    // minimum clipping angle
    float min_angle = start_stop.x;
    // maximum clipping angle
    float max_angle = start_stop.y;
    // a is negative only when angle is in the interval [min_angle, max_angle]
    float a = -(angle - min_angle) * (max_angle - angle);
    // alpha is zero when a is negative and it is tint.w when a is positive
    float alpha = step(0.0, a) * tint.w;
    // premultiply    
    lowp vec4 tint_pm = vec4(tint.xyz * alpha, alpha);
    // sample the texture color and apply tint
    vec4 color = texture2D(texture_sampler, var_texcoord0.xy) * tint_pm;

    gl_FragColor = color;
}